﻿/*
 * CKEditor - The text editor for Internet - http://ckeditor.com
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 */

/**
 * @fileOverview Defines the {@link CKEDITOR.dom.node} class, which is the base
 *		class for classes that represent DOM nodes.
 */

/**
 * Base class for classes representing DOM nodes.
 * @constructor
 * @see CKEDITOR.dom.element
 * @example
 */
CKEDITOR.dom.node = function()
{};

CKEDITOR.dom.node.prototype =
{
	/**
	 * Makes this node child of another element.
	 * @param {CKEDITOR.dom.element} element The target element to which append
	 *		this node.
	 * @returns {CKEDITOR.dom.element} The target element.
	 * @example
	 * var p = new CKEDITOR.dom.element( 'p' );
	 * var strong = new CKEDITOR.dom.element( 'strong' );
	 * strong.appendTo( p );
	 *
	 * // result: "&lt;p&gt;&lt;strong&gt;&lt;/strong&gt;&lt;/p&gt;"
	 */
	appendTo : function( element )
	{
		element.append( this );
		return element;
	},

	/**
	 * Inserts this element after a node.
	 * @param {CKEDITOR.dom.node} node The that will preceed this element.
	 * @returns {CKEDITOR.dom.node} The node preceeding this one after
	 *		insertion.
	 * @example
	 * var em = new CKEDITOR.dom.element( 'em' );
	 * var strong = new CKEDITOR.dom.element( 'strong' );
	 * strong.insertAfter( em );
	 *
	 * // result: "&lt;em&gt;&lt;/em&gt;&lt;strong&gt;&lt;/strong&gt;"
	 */
	insertAfter : function( node )
	{
		node.$.parentNode.insertBefore( this.$, node.$.nextSibling );
		return node;
	},

	/**
	 * Inserts this element before a node.
	 * @param {CKEDITOR.dom.node} node The that will be after this element.
	 * @returns {CKEDITOR.dom.node} The node after this one after insertion.
	 * @example
	 * var em = new CKEDITOR.dom.element( 'em' );
	 * var strong = new CKEDITOR.dom.element( 'strong' );
	 * strong.insertBefore( em );
	 *
	 * // result: "&lt;strong&gt;&lt;/strong&gt;&lt;em&gt;&lt;/em&gt;"
	 */
	insertBefore : function( node )
	{
		node.$.parentNode.insertBefore( this.$, node.$ );
	}
};
